# airless-core

[![PyPI version](https://badge.fury.io/py/airless-core.svg)](https://badge.fury.io/py/airless-core)

airless-core have the core components for [Airless](https://github.com/astercapital/airless) to work.
